==> haskell-hasql-pool-0.4.3-55-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.4.3
id: hasql-pool-0.4.3-EQfl6pwrCroH76tk6iUH1v
key: hasql-pool-0.4.3-EQfl6pwrCroH76tk6iUH1v
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
abi: ecd0f8b5fb6713d0d0f78a0777d416fa
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-pool-0.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-pool-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hasql-pool-0.4.3
hs-libraries: HShasql-pool-0.4.3-EQfl6pwrCroH76tk6iUH1v
depends:
    resource-pool-0.2.3.2-JnmLkNozjiKHQJsjkBGvI2
    hasql-1.1.1-DOCueAN5GRu59d93saj0Zu time-1.8.0.2
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm
abi-depends: resource-pool-0.2.3.2-JnmLkNozjiKHQJsjkBGvI2=dc9bedd5baacc22688739eb21b98c2f7
             hasql-1.1.1-DOCueAN5GRu59d93saj0Zu=1d3b400d61e48cf1ff242f1ebdfa9b03
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=3e78347d5a15e89f4fb1084b18368182
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.4.3-56-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.4.3
id: hasql-pool-0.4.3-LOm2Pzo6aVO87Gby44Fq2a
key: hasql-pool-0.4.3-LOm2Pzo6aVO87Gby44Fq2a
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
abi: 73e71a51c68552ebc6c85389e4f71d47
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-pool-0.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-pool-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hasql-pool-0.4.3
hs-libraries: HShasql-pool-0.4.3-LOm2Pzo6aVO87Gby44Fq2a
depends:
    resource-pool-0.2.3.2-JnmLkNozjiKHQJsjkBGvI2
    hasql-1.1.1-222qfNailiP756CsCrpOQm time-1.8.0.2
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm
abi-depends: resource-pool-0.2.3.2-JnmLkNozjiKHQJsjkBGvI2=dc9bedd5baacc22688739eb21b98c2f7
             hasql-1.1.1-222qfNailiP756CsCrpOQm=ffa5e13773cc4a93db205c7d23a46cbf
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=3e78347d5a15e89f4fb1084b18368182
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
